@@ -1,4 +1,4 @@
-from config import Config as conf
+from qa_data_manager.config import Config as conf
 from qa_data_manager.data_base_model import database
 
 """
